nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Cfg

Struct Cfg 

#[repr(transparent)]
pub struct Cfg(pub u32);
Configuration Register

Tuple Fields

0: u32

Implementations

Source

impl Cfg

pub const fn adctrl(&self) -> u16

Controls the maximum value of a variable delay that will be applied before any ELS AES operation is started

pub const fn set_adctrl(&mut self, val: u16)

Controls the maximum value of a variable delay that will be applied before any ELS AES operation is started