#[repr(transparent)]pub struct DmaRes0Len(pub u32);Expand description
DMA Result 0 Length
Tuple Fields
0: u32Implementations
Sourceimpl DmaRes0Len
impl DmaRes0Len
Sourcepub const fn size_res0_len(&self) -> u32
pub const fn size_res0_len(&self) -> u32
Size in bytes of the data to be transferred
Sourcepub const fn set_size_res0_len(&mut self, val: u32)
pub const fn set_size_res0_len(&mut self, val: u32)
Size in bytes of the data to be transferred