nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

DmaSrc0

Struct DmaSrc0 

#[repr(transparent)]
pub struct DmaSrc0(pub u32);
DMA Source 0

Tuple Fields

0: u32

Implementations

Source

impl DmaSrc0

pub const fn addr_src0(&self) -> u32

Defines the system address of the start of the data to be transferred to the ELS via DMA.

pub const fn set_addr_src0(&mut self, val: u32)

Defines the system address of the start of the data to be transferred to the ELS via DMA.