#[repr(transparent)]pub struct DmaSrc0Len(pub u32);Expand description
DMA Source 0 Length
Tuple Fields
0: u32Implementations
Sourceimpl DmaSrc0Len
impl DmaSrc0Len
Sourcepub const fn size_src0_len(&self) -> u32
pub const fn size_src0_len(&self) -> u32
Size in bytes of the data to be transferred from the target defined in SFR DMA_SRC0.
Sourcepub const fn set_size_src0_len(&mut self, val: u32)
pub const fn set_size_src0_len(&mut self, val: u32)
Size in bytes of the data to be transferred from the target defined in SFR DMA_SRC0.