nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

DmaSrc1

Struct DmaSrc1 

#[repr(transparent)]
pub struct DmaSrc1(pub u32);
DMA Source 1

Tuple Fields

0: u32

Implementations

Source

impl DmaSrc1

pub const fn addr_src1(&self) -> u32

Defines the system address of the start of the data to be transferred to the ELS via DMA.

pub const fn set_addr_src1(&mut self, val: u32)

Defines the system address of the start of the data to be transferred to the ELS via DMA.