nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

DmaSrc2Len

Struct DmaSrc2Len 

#[repr(transparent)]
pub struct DmaSrc2Len(pub u32);
DMA Source 2 Length

Tuple Fields

0: u32

Implementations

Source

impl DmaSrc2Len

pub const fn size_src2_len(&self) -> u32

Size in bytes of the data to be transferred from the target defined in SFR DMA_SRC2.

pub const fn set_size_src2_len(&mut self, val: u32)

Size in bytes of the data to be transferred from the target defined in SFR DMA_SRC2.