#[repr(transparent)]pub struct Cfg(pub u32);Expand description
Configuration Register
Tuple Fields
0: u32Implementations
Sourceimpl Cfg
impl Cfg
Sourcepub const fn adctrl(&self) -> u16
pub const fn adctrl(&self) -> u16
Controls the maximum value of a variable delay that will be applied before any ELS AES operation is started
Sourcepub const fn set_adctrl(&mut self, val: u16)
pub const fn set_adctrl(&mut self, val: u16)
Controls the maximum value of a variable delay that will be applied before any ELS AES operation is started